@@ -1,56 +1,19 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2020 CERN.
+# Copyright (C) 2016-2021 CERN.
 #
 # Marshmallow-Utils is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
 
 """HTML sanitized string field."""
 
-import bleach
+from marshmallow import fields
 
-from .sanitizedunicode import SanitizedUnicode
-
-#: Allowed tags used for html sanitizing by bleach.
-ALLOWED_HTML_TAGS = [
-    'a',
-    'abbr',
-    'acronym',
-    'b',
-    'blockquote',
-    'br',
-    'code',
-    'div',
-    'em',
-    'h1',
-    'h2',
-    'h3',
-    'h4',
-    'h5',
-    'i',
-    'li',
-    'ol',
-    'p',
-    'pre',
-    'span',
-    'strike',
-    'strong',
-    'sub',
-    'sup',
-    'u',
-    'ul',
-]
-
-#: Allowed attributes used for html sanitizing by bleach.
-ALLOWED_HTML_ATTRS = {
-    '*': ['class'],
-    'a': ['href', 'title', 'name', 'class', 'rel'],
-    'abbr': ['title'],
-    'acronym': ['title'],
-}
+# For backward compatibility we import ALLOWED_* variables.
+from ..html import ALLOWED_HTML_ATTRS, ALLOWED_HTML_TAGS, sanitize_html
 
 
-class SanitizedHTML(SanitizedUnicode):
+class SanitizedHTML(fields.String):
     """String field which sanitizes HTML using the bleach library.
 
     The default list of allowed tags and attributes is defined by
@@ -67,8 +30,7 @@ class SanitizedHTML(SanitizedUnicode):
     :param attrs: Dictionary of allowed attributes per tag.
     """
 
-    def __init__(self, tags=ALLOWED_HTML_TAGS, attrs=ALLOWED_HTML_ATTRS, *args,
-                 **kwargs):
+    def __init__(self, tags=None, attrs=None, *args, **kwargs):
         """Initialize field."""
         super().__init__(*args, **kwargs)
         self.tags = tags
@@ -78,9 +40,4 @@ class SanitizedHTML(SanitizedUnicode):
         """Deserialize string by sanitizing HTML."""
         value = super()._deserialize(
             value, attr, data, **kwargs)
-        return bleach.clean(
-            value,
-            tags=self.tags,
-            attributes=self.attrs,
-            strip=True,
-        ).strip()
+        return sanitize_html(value, tags=self.tags, attrs=self.attrs)
