@@ -6,6 +6,6 @@
 # Marshmallow-Utils is free software; you can redistribute it and/or modify
 # it under the terms of the MIT License; see LICENSE file for more details.
 
-check-manifest --ignore ".travis-*" && \
+check-manifest --ignore ".*-requirements.txt" && \
 sphinx-build -qnNW docs docs/_build/html && \
 pytest
