@@ -8,7 +8,7 @@
 
 """Test the marshmallow fields."""
 
-from datetime import date
+from datetime import date, datetime
 
 import pytest
 from marshmallow import EXCLUDE, Schema, ValidationError, missing
@@ -59,13 +59,15 @@ def test_stripped_html():
         'f': 'an evil() example'}
 
     # Ensure already escaped HTML is returned unescaped.
-    class ASchema(Schema):
-        f = fields.StrippedHTML()
-
     assert ASchema().dump(
         {'f': 'an <div>&lt;span&gt;example&lt;/span&gt;</div>'}) == {
         'f': 'an <span>example</span>'}
 
+    # Unwanted unicode chars from HTML entities should also be removed.
+    assert ASchema().dump(
+        {'f': 'an &#8203;&quot;example&quot;'}) == {
+        'f': 'an "example"'}
+
 
 def test_isodate():
     """Test ISO date formatted string."""
@@ -81,6 +83,19 @@ def test_isodate():
     pytest.raises(ValidationError, ASchema().load, {'f': 'invalid'})
 
 
+def test_tzdatetime():
+    """Test ISO date formatted string with timezone."""
+    class ASchema(Schema):
+        f = fields.TZDateTime()
+
+    example_date = datetime(2017, 11, 28, 23, 55, 59, 342380)
+    expected_date = '2017-11-28T23:55:59.342380+00:00'
+    assert ASchema().dump({'f': example_date}) == {'f': expected_date}
+
+    # Test serialization of None values
+    assert ASchema().dump({'f': None}) == {'f': None}
+
+
 def test_generated():
     """Test fields.generated fields."""
 
